<?php

namespace Drupal\super_sitemap\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\Core\Url;
use Drupal\simple_sitemap\Entity\SimpleSitemap;

/**
 * Extend SimpleSitemap config entity class to customize it.
 */
class SuperSitemap extends SimpleSitemap {

  /**
   * Override SimpleSitemap::toUrl().
   */
  public function toUrl($rel = 'canonical', array $options = []) {
    // Use SimpleSitemap::toUrl for non-canonical and default variant
    // URL generation.
    if ($rel !== 'canonical' || $this->isDefault()) {
      return parent::toUrl($rel, $options);
    }

    // Replicate SimpleSitemap::toUrl logic for non-default variant URL generation.
    $parameters = isset($options['delta']) ? ['page' => $options['delta']] : [];
    unset($options['delta']);

    if (empty($options['base_url'])) {
      /** @var \Drupal\simple_sitemap\Settings $settings */
      $settings = \Drupal::service('simple_sitemap.settings');
      $options['base_url'] = $settings->get('base_url') ?: $GLOBALS['base_url'];
    }

    $options['path_processing'] = FALSE;

    // Use super_sitemap.sitemap_variant route instead of simple_sitemap.sitemap_variant route.
    return Url::fromRoute(
        'super_sitemap.sitemap_variant',
        $parameters + ['variant' => $this->id()],
        $options);
  }

}
