<?php

declare(strict_types=1);

namespace Drupal\super_sitemap\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\super_sitemap\SuperSitemapDataSourceInterface;

/**
 * Defines the Super Sitemap data source entity type.
 *
 * @ConfigEntityType(
 *   id = "super_sitemap_data_source",
 *   label = @Translation("Super Sitemap Data Source"),
 *   label_collection = @Translation("Super Sitemap Data Sources"),
 *   label_singular = @Translation("super Sitemap Data Source"),
 *   label_plural = @Translation("Super Sitemap Data Sources"),
 *   label_count = @PluralTranslation(
 *     singular = "@count Super Sitemap Data Source",
 *     plural = "@count Super Sitemap Data Sources",
 *   ),
 *   handlers = {
 *     "list_builder" = "Drupal\super_sitemap\SuperSitemapDataSourceListBuilder",
 *     "form" = {
 *       "add" = "Drupal\super_sitemap\Form\SuperSitemapDataSourceForm",
 *       "edit" = "Drupal\super_sitemap\Form\SuperSitemapDataSourceForm",
 *       "delete" = "Drupal\Core\Entity\EntityDeleteForm",
 *     },
 *   },
 *   config_prefix = "super_sitemap_data_source",
 *   admin_permission = "administer sitemap settings",
 *   links = {
 *     "collection" = "/admin/config/search/simplesitemap/super-extras/data-sources",
 *     "add-form" = "/admin/config/search/simplesitemap/super-extras/data-sources/add",
 *     "edit-form" = "/admin/config/search/simplesitemap/super-extras/data-sources/{super_sitemap_data_source}",
 *     "delete-form" = "/admin/config/search/simplesitemap/super-extras/data-sources/{super_sitemap_data_source}/delete",
 *   },
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid",
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "description",
 *     "sitemap",
 *     "xml_source"
 *   },
 * )
 */
final class SuperSitemapDataSource extends ConfigEntityBase implements SuperSitemapDataSourceInterface {

  /**
   * The data source ID.
   */
  protected string $id;

  /**
   * The data source label.
   */
  protected string $label;

  /**
   * The data source description.
   */
  protected string $description;

  /**
   * The data source sitemap value.
   */
  protected string $sitemap;

  /**
   * The data source xml source value.
   */
  protected string $xml_source;

  /**
   * Get the data source description.
   */
  public function getDescription() {
    return $this->get('description');
  }

  /**
   * Get the data source sitemap.
   */
  public function getSitemap() {
    return $this->get('sitemap');
  }

  /**
   * Get the data source xml_source.
   */
  public function getXmlSource() {
    return $this->get('xml_source');
  }

}
