<?php

namespace Drupal\super_sitemap\Event;

use Drupal\Component\EventDispatcher\Event;
use Drupal\super_sitemap\SuperSitemapDataSourceInterface;

class SuperSitemapDataSourceRequestEvent extends Event {

  /**
   * The data source entity.
   *
   * @var \Drupal\super_sitemap\SuperSitemapDataSourceInterface
   */
  protected $dataSource;

  /**
   * The options for the data source request being updated.
   *
   * @var array
   */
  protected $options;

  /**
   * The url for the data source request.
   *
   * @var string
   */
  protected $url;

  /**
   * Constructs ConfigImporterEvent.
   *
   * @param \Drupal\super_sitemap\SuperSitemapDataSourceInterface $data_source
   *   A data source entity.
   * @param string $url
   *   The URL to query.
   * @param array $options
   *   The options to set for the query to the data source.
   */
  public function __construct(
    SuperSitemapDataSourceInterface $data_source,
    string &$url,
    array &$options
  ) {
    $this->dataSource = $data_source;
    $this->url = &$url;
    $this->options = &$options;
  }

  /**
   * Get the request options.
   *
   * @return array
   *   The array of options for the request.
   */
  public function getOptions() {
    return $this->options;
  }

  /**
   * Get the request url.
   *
   * @return string
   *   The url for the request.
   */
  public function getUrl() {
    return $this->url;
  }

}
