<?php

namespace Drupal\super_sitemap\Event;

/**
 * Contains all events thrown while processing sitemaps with Super Sitemap.
 */
final class SuperSitemapEvents {

  /**
   * The name of the event triggered when building an API request.
   *
   * This event allows modules to react to a request made by the Super Sitemap
   * module when making requests to endpoints. This allows modifying the request
   * before its sent to set a payload (for POST requests) and authentication
   * (if required).
   *
   * @Event
   *
   *  @var string
   */
  const BUILD_OPTIONS = 'super_sitemap.data_source.build_request_options';

  /**
   * The name of the event triggered to alter results from a data request.
   *
   * This event allows modules to apply formatting to incoming data from a
   * request made by the Super Sitemap module when making requests to endpoints.
   * This allows modifying the response to ensure it's formatted in a way
   * Simple Sitemap expects before handing it off the Simple Sitemp system.
   *
   * The result should use the following options where URL is the only required
   * value based on the options at https://www.sitemaps.org/protocol.html:
   * [
   *   'url' => URL of the page,
   *   'lastmod' => Date the page was last updated in ISO 8601 date format,
   *   'priority' => The importance of the page (usually 0.5),
   *   'changefreq' => How often this page changes,
   * ]
   *
   * @Event
   *
   *  @var string
   */
  const FORMAT_RESULTS = 'super_sitemap.data_source.format_results';

}
