<?php

declare(strict_types=1);

namespace Drupal\super_sitemap\Form;

use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Form controller for the super_sitemap_custom_url entity edit forms.
 */
final class SuperSitemapCustomUrlForm extends ContentEntityForm {

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state): int {
    $result = parent::save($form, $form_state);

    $message_args = ['%label' => $this->entity->toLink()->toString()];
    $logger_args = [
      '%label' => $this->entity->label(),
      'link' => $this->entity->toLink($this->t('View'))->toString(),
    ];

    switch ($result) {
      case SAVED_NEW:
        $this->messenger()->addStatus($this->t('New Custom URL %label has been created.', $message_args));
        $this->logger('cphub_alerts')->notice('New Custom URL %label has been created.', $logger_args);
        break;

      case SAVED_UPDATED:
        $this->messenger()->addStatus($this->t('The Custom URL %label has been updated.', $message_args));
        $this->logger('cphub_alerts')->notice('The Custom URL %label has been updated.', $logger_args);
        break;

      default:
        throw new \LogicException('Could not save the Custom URL.');
    }

    // Redirect to the super sitemap custom url dashboard page.
    $url = Url::fromRoute('entity.super_sitemap_custom_url.collection');
    $form_state->setRedirectUrl($url);

    return $result;
  }

}
