<?php

namespace Drupal\super_sitemap\Plugin\simple_sitemap\UrlGenerator;

use Drupal\Core\Url;
use Drupal\simple_sitemap\Logger;
use Drupal\simple_sitemap\Plugin\simple_sitemap\SimpleSitemapPluginBase;
use Drupal\simple_sitemap\Plugin\simple_sitemap\UrlGenerator\UrlGeneratorBase;
use Drupal\simple_sitemap\Settings;
use Drupal\super_sitemap\Manager\SuperSitemapGenerator;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides the custom URL generator.
 *
 * @UrlGenerator(
 *   id = "external_custom_url",
 *   label = @Translation("External Link Custom URL generator"),
 *   description = @Translation("Generates URLs set in admin/config/search/simplesitemap/custom."),
 * )
 */
class ExternalCustomUrlGenerator extends UrlGeneratorBase {

  /**
   * The simple_sitemap.external_custom_url_manager service.
   *
   * @var \Drupal\super_sitemap\Manager\SuperSitemapGenerator
   */
  protected $generator;

  /**
   * CustomUrlGenerator constructor.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\simple_sitemap\Logger $logger
   *   Simple XML Sitemap logger.
   * @param \Drupal\simple_sitemap\Settings $settings
   *   The simple_sitemap.settings service.
   * @param \Drupal\Core\Language\LanguageManagerInterface $language_manager
   *   The language manager.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\simple_sitemap\Entity\EntityHelper $entity_helper
   *   Helper class for working with entities.
   * @param \Drupal\super_sitemap\Manager\SuperSitemapGenerator $generator
   *   The simple_sitemap.external_custom_url_manager service.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    Logger $logger,
    Settings $settings,
    SuperSitemapGenerator $generator) {
    parent::__construct(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $logger,
      $settings
    );
    $this->generator = $generator;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(
    ContainerInterface $container,
    array $configuration,
    $plugin_id,
    $plugin_definition): SimpleSitemapPluginBase {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('simple_sitemap.logger'),
      $container->get('simple_sitemap.settings'),
      $container->get('super_sitemap.generator')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDataSets(): array {
    $custom_link_settings = $this->generator->setSitemaps($this->sitemap)->get();
    $custom_link_settings = $custom_link_settings ? reset($custom_link_settings) : [];
    return array_values($custom_link_settings);
  }

  /**
   * {@inheritdoc}
   */
  protected function processDataSet($data_set): array {
    $url_object = Url::fromUserInput($data_set['path'])->setAbsolute();

    $path_data = [
      'url' => $url_object,
      'priority' => $data_set['priority'] ?? NULL,
      'changefreq' => !empty($data_set['changefreq']) ? $data_set['changefreq'] : NULL,
    ];

    return $path_data;
  }

}
