<?php

namespace Drupal\super_sitemap\Routing;

use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Routing\Route;

/**
 * Super Sitemap Variant Route.
 *
 * @package Drupal\super_sitemap\Routing
 */
class SitemapVariant implements ContainerInjectionInterface {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Constructs a new SitemapVariantRoutes object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   * *   The config factory.
 */
  public function __construct(ConfigFactory $config_factory) {
    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory')
    );
  }

  /**
   * Dynamically generate the routes using configured base path.
   */
  public function routes(): array {
    $routes = [];

    $base_path = $this->configFactory
      ->get('super_sitemap.settings')
      ->get('default_base_path');

    // Declare route similar to simple_sitemap.sitemap_variant route.
    $routes['super_sitemap.sitemap_variant'] = new Route(
      $base_path . '/{variant}/sitemap.xml',
      [
        '_controller' => '\Drupal\simple_sitemap\Controller\SimpleSitemapController::getSitemap',
        '_disable_route_normalizer' => TRUE,
      ],
      [
        '_access' => 'TRUE',
      ]
    );

    return $routes;

  }
}
